@@ -27,7 +27,7 @@
  *  This is source code modified by FUJITSU LIMITED under the Joint
  *  Development Agreement for the CDE/Motif PST.
  */
-/* $XFree86: xc/lib/X11/lcGeneric.c,v 3.21 2006/01/09 14:58:43 dawes Exp $ */
+/* $XFree86: xc/lib/X11/lcGeneric.c,v 3.22 2007/04/09 15:37:12 tsi Exp $ */
 
 #include <stdio.h>
 #include "Xlibint.h"
@@ -426,7 +426,7 @@ read_charset_define(
     char name[BUFSIZ];
     XlcCharSet charsetd;
     char **value;
-    int num, new;
+    int num, new = 0;
     XlcSide side = XlcUnknown;
     char *tmp;
 
