@@ -44,7 +44,7 @@ ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 SOFTWARE.
 
 ******************************************************************/
-/* $XFree86: xc/lib/Xt/TranslateI.h,v 1.6 2006/01/09 14:59:23 dawes Exp $ */
+/* $XFree86: xc/lib/Xt/TranslateI.h,v 1.7 2006/12/10 15:58:24 tsi Exp $ */
 
 /*
  * TranslateI.h - Header file private to translation management
@@ -259,7 +259,7 @@ typedef struct _TMConvertRec {
     XtTranslations	new; /* table to merge from */
 } TMConvertRec;
 
-#define _XtEventTimerEventType ((TMLongCard)~0L)
+#define _XtEventTimerEventType ((TMLongCard)~0U)
 #define KeysymModMask		(1L<<27) /* private to TM */
 #define AnyButtonMask		(1L<<28) /* private to TM */
 
