@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/Xserver/GL/dri/xf86dri.c,v 1.13 2003/09/24 02:43:12 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/GL/dri/xf86dri.c,v 1.16 2007/01/04 02:48:10 tsi Exp $ */
 /**************************************************************************
 
 Copyright 1998-1999 Precision Insight, Inc., Cedar Park, Texas.
@@ -35,15 +35,15 @@ SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  *
  */
 
-#ifdef XFree86LOADER
 #include "xf86.h"
+#ifdef XFree86LOADER
 #include "xf86_ansic.h"
 #endif
 
 #define NEED_REPLIES
 #define NEED_EVENTS
-#include "X.h"
-#include "Xproto.h"
+#include <X11/X.h>
+#include <X11/Xproto.h>
 #include "misc.h"
 #include "dixstruct.h"
 #include "extnsionst.h"
@@ -54,6 +54,7 @@ SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #define _XF86DRI_SERVER_
 #include "xf86dristr.h"
 #include "swaprep.h"
+#include "xf86str.h"
 #include "dri.h"
 #include "sarea.h"
 #include "dristruct.h"
@@ -85,10 +86,8 @@ static void XF86DRIResetProc(ExtensionEntry* extEntry);
 
 static unsigned char DRIReqCode = 0;
 
-extern void XFree86DRIExtensionInit(void);
-
 void
-XFree86DRIExtensionInit(void)
+XFree86DRIExtensionInit(INITARGS)
 {
     ExtensionEntry* extEntry;
 
@@ -184,7 +183,7 @@ ProcXF86DRIOpenConnection(
 )
 {
     xXF86DRIOpenConnectionReply rep;
-    drmHandle			hSAREA;
+    drm_handle_t			hSAREA;
     char*			busIdString;
 
     REQUEST(xXF86DRIOpenConnectionReq);
@@ -340,7 +339,7 @@ ProcXF86DRICreateContext(
     if (!DRICreateContext( pScreen,
 			   visual,
 			   stuff->context,
-			   (drmContextPtr)&rep.hHWContext)) {
+			   (drm_context_t *)&rep.hHWContext)) {
 	return BadValue;
     }
 
@@ -397,7 +396,7 @@ ProcXF86DRICreateDrawable(
     if (!DRICreateDrawable( screenInfo.screens[stuff->screen],
 			    (Drawable)stuff->drawable,
 			    pDrawable,
-			    (drmDrawablePtr)&rep.hHWDrawable)) {
+			    (drm_drawable_t *)&rep.hHWDrawable)) {
 	return BadValue;
     }
 
@@ -442,8 +441,8 @@ ProcXF86DRIGetDrawableInfo(
     xXF86DRIGetDrawableInfoReply	rep;
     DrawablePtr pDrawable;
     int X, Y, W, H;
-    XF86DRIClipRectPtr pClipRects;
-    XF86DRIClipRectPtr pBackClipRects;
+    drm_clip_rect_t * pClipRects;
+    drm_clip_rect_t * pBackClipRects;
     int backX, backY;
 
     REQUEST(xXF86DRIGetDrawableInfoReq);
@@ -492,10 +491,10 @@ ProcXF86DRIGetDrawableInfo(
     rep.backY = backY;
         
     if (rep.numBackClipRects) 
-       rep.length += sizeof(XF86DRIClipRectRec) * rep.numBackClipRects;    
+       rep.length += sizeof(drm_clip_rect_t) * rep.numBackClipRects;    
 
     if (rep.numClipRects) 
-       rep.length += sizeof(XF86DRIClipRectRec) * rep.numClipRects;
+       rep.length += sizeof(drm_clip_rect_t) * rep.numClipRects;
     
     rep.length = ((rep.length + 3) & ~3) >> 2;
 
@@ -503,13 +502,13 @@ ProcXF86DRIGetDrawableInfo(
 
     if (rep.numClipRects) {
 	WriteToClient(client,  
-		      sizeof(XF86DRIClipRectRec) * rep.numClipRects,
+		      sizeof(drm_clip_rect_t) * rep.numClipRects,
 		      (char *)pClipRects);
     }
 
     if (rep.numBackClipRects) {
        WriteToClient(client, 
-		     sizeof(XF86DRIClipRectRec) * rep.numBackClipRects,
+		     sizeof(drm_clip_rect_t) * rep.numBackClipRects,
 		     (char *)pBackClipRects);
     }
 
@@ -522,7 +521,7 @@ ProcXF86DRIGetDeviceInfo(
 )
 {
     xXF86DRIGetDeviceInfoReply	rep;
-    drmHandle hFrameBuffer;
+    drm_handle_t hFrameBuffer;
     void *pDevPrivate;
 
     REQUEST(xXF86DRIGetDeviceInfoReq);
