@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/Xserver/hw/darwin/quartz/applewm.c,v 1.3 2003/11/11 23:48:41 torrey Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/darwin/quartz/applewm.c,v 1.5 2007/04/03 00:21:09 tsi Exp $ */
 /**************************************************************************
 
 Copyright (c) 2002 Apple Computer, Inc. All Rights Reserved.
@@ -40,10 +40,11 @@ SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include "windowstr.h"
 #include "servermd.h"
 #include "swaprep.h"
-#include "Xatom.h"
+#include "propertyst.h"
+#include <X11/Xatom.h>
 #include "darwin.h"
 #define _APPLEWM_SERVER_
-#include "applewmstr.h"
+#include <X11/extensions/applewmstr.h>
 #include "applewmExt.h"
 
 #define DEFINE_ATOM_HELPER(func,atom_name)			\
@@ -58,6 +59,7 @@ static Atom func (void) {					\
 }
 
 DEFINE_ATOM_HELPER(xa_native_screen_origin, "_NATIVE_SCREEN_ORIGIN")
+DEFINE_ATOM_HELPER(xa_apple_no_order_in, "_APPLE_NO_ORDER_IN")
 
 static AppleWMProcsPtr appleWMProcs;
 
@@ -152,6 +154,29 @@ AppleWMSetScreenOrigin(
                          32, PropModeReplace, 2, data, TRUE);
 }
 
+/* Window managers can set the _APPLE_NO_ORDER_IN property on windows
+   that are being genie-restored from the Dock. We want them to
+   be mapped but remain ordered-out until the animation
+   completes (when the Dock will order them in). */
+Bool
+AppleWMDoReorderWindow(
+    WindowPtr pWin
+)
+{
+    Atom atom;
+    PropertyPtr prop;
+
+    atom = xa_apple_no_order_in();
+    for (prop = wUserProps(pWin); prop != NULL; prop = prop->next)
+    {
+        if (prop->propertyName == atom && prop->type == atom)
+            return FALSE;
+    }
+
+    return TRUE;
+}
+
+
 static int
 ProcAppleWMQueryVersion(
     register ClientPtr client
@@ -572,7 +597,7 @@ ProcAppleWMFrameDraw(
 {
     BoxRec ir, or;
     unsigned int title_length, title_max;
-    unsigned char *title_bytes;
+    char *title_bytes;
     REQUEST(xAppleWMFrameDrawReq);
     WindowPtr pWin;
 
@@ -593,7 +618,7 @@ ProcAppleWMFrameDraw(
     if (title_max < title_length)
         return BadValue;
 
-    title_bytes = (unsigned char *) &stuff[1];
+    title_bytes = (char *) &stuff[1];
 
     errno = appleWMProcs->FrameDraw(pWin, stuff->frame_class,
                                     stuff->frame_attr, &or, &ir,
