@@ -1,6 +1,6 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/ati/atiprint.h,v 1.12 2004/12/31 16:07:06 tsi Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/ati/atiprint.h,v 1.16 2008/01/01 00:40:01 tsi Exp $ */
 /*
- * Copyright 1997 through 2005 by Marc Aurele La France (TSI @ UQV), tsi@xfree86.org
+ * Copyright 1997 through 2008 by Marc Aurele La France (TSI @ UQV), tsi@xfree86.org
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -29,6 +29,9 @@
 
 #include "xf86str.h"
 
+extern void ATIPrintMemory    FunctionPrototype((const CARD8 *,
+                                                 const unsigned int,
+                                                 const int));
 extern void ATIPrintBIOS      FunctionPrototype((const CARD8 *,
                                                  const unsigned int));
 extern void ATIPrintRegisters FunctionPrototype((ATIPtr));
