@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/s3virge/newmmio.h,v 1.6 2004/02/13 23:58:43 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/s3virge/newmmio.h,v 1.7 2005/10/14 15:16:43 tsi Exp $ */
 
 /*
  * Copyright (C) 1994-1999 The XFree86 Project, Inc.
@@ -72,9 +72,7 @@
 #define S3_NEWMMIO_REGSIZE	  0x10000  /* 64KB */
 #define S3V_MMIO_REGSIZE	   0x8000  /* 32KB */
 
-
-/* #include <Xmd.h> */
-
+#include <X11/Xmd.h>
 
 #define int16	CARD16
 #define int32	CARD32
