@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/etc/scanpci.c,v 3.100 2008/03/26 18:57:50 tsi Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/etc/scanpci.c,v 3.101 2008/04/24 20:10:12 tsi Exp $ */
 /*
  * Copyright 2000 by Egbert Eich
  * Copyright 1995 by Robin Cutshaw <robin@XFree86.Org>
@@ -339,7 +339,18 @@ dump_config(pciConfigPtr pcr, int verbose)
 
     /* Print the rest */
     for (;  i < limit;  i += 4) {
-	CARD32 pcireg = pciReadLong(pcr->tag, i);
+	CARD32 pcireg;
+
+	/*
+	 * Avoid the interrupt acknowledge cycle that is generated on a Simba's
+	 * secondary bus when its 0xb8 register is read.
+	 */
+	if ((pcr->pci_device_vendor == DEVID(VENDOR_SUN, CHIP_SIMBA)) &&
+	    (i == 0x00b8))
+	    pcireg = (CARD32)(-1L);	/* Simulate a master abort */
+	else
+	    pcireg = pciReadLong(pcr->tag, i);
+
 	if ((pcireg == (CARD32)(-1L)) && (i == 256))
 	    break;
 	if (!(i & 15))
