@@ -11,7 +11,7 @@ the suitability of this software for any purpose.  It is provided "as
 is" without express or implied warranty.
 
 */
-/* $XFree86: xc/programs/Xserver/hw/xnest/Init.c,v 3.28 2006/02/19 15:51:30 tsi Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xnest/Init.c,v 3.32 2007/04/03 00:21:13 tsi Exp $ */
 /*
  * Copyright (c) 1996-2004 by The XFree86 Project, Inc.
  * All rights reserved.
@@ -69,6 +69,7 @@ is" without express or implied warranty.
 #include "servermd.h"
 #include "mi.h"
 #include <X11/fonts/fontstruct.h>
+#include "extnsionst.h"
 
 #include "Xnest.h"
 
@@ -86,7 +87,7 @@ is" without express or implied warranty.
 Bool xnestDoFullGeneration = True;
 
 void
-InitOutput(ScreenInfo *screenInfo, int argc, char *argv[])
+InitOutput(ScreenInfo *screenInfo, const int argc, const char *argv[])
 {
   int i, j;
 
@@ -127,7 +128,7 @@ InitOutput(ScreenInfo *screenInfo, int argc, char *argv[])
 }
 
 void
-InitInput(int argc, char *argv[])
+InitInput(const int argc, const char *argv[])
 {
   pointer ptr, kbd;
 
@@ -161,15 +162,15 @@ void ddxGiveUp()
 
 #ifdef __DARWIN__
 void
-DarwinHandleGUI(int argc, char *argv[])
+DarwinHandleGUI(int argc, const char *argv[], char *envp[])
 {
 }
 
-void GlxExtensionInit();
+void GlxExtensionInit(INITARGS);
 void GlxWrapInitVisuals(void *procPtr);
 
 void
-DarwinGlxExtensionInit()
+DarwinGlxExtensionInit(INITARGS)
 {
     GlxExtensionInit();
 }
